@@ -25,6 +25,7 @@ use warnings;
 
 use MYDan;
 use Digest::MD5;
+use MYDan::Util::FastMD5;
 
 sub new
 {
@@ -45,9 +46,7 @@ sub save
     my $tempmd5 = Digest::MD5->new()->add( $file.time,$$ )->hexdigest();
     die "save fail: $!" if system "cp '$file' '$path/$tempmd5.tmp'";
 
-    open my $fh, "<$path/$tempmd5.tmp" or die "open fail: $!";
-    my $md5 = Digest::MD5->new()->addfile( $fh )->hexdigest();
-    close $fh;
+    my $md5 = MYDan::Util::FastMD5->hexdigest( "$path/$tempmd5.tmp" );
 
     die "save fail: $!" if system "mv '$path/$tempmd5.tmp' '$path/$md5'";
     
@@ -69,12 +68,7 @@ sub fastsave
     my $cp = $dev[0] eq $dev[1] ? 'ln' : 'cp';
     die "save fail: $!" if system "$cp '$file' '$path/$tempmd5.tmp'";
 
-    unless( $md5 )
-    {
-        open my $fh, "<$path/$tempmd5.tmp" or die "open fail: $!";
-        $md5 = Digest::MD5->new()->addfile( $fh )->hexdigest();
-        close $fh;
-    }
+    $md5 = MYDan::Util::FastMD5->hexdigest( "$path/$tempmd5.tmp" ) unless $md5;
 
     die "save fail: $!" if system "mv '$path/$tempmd5.tmp' '$path/$md5'";
     
